==> haskell-hslua-classes-2.3.0-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-classes
version:              2.3.0
visibility:           public
id:                   hslua-classes-2.3.0-IHHHpBW0JcmD7Uey6ib0yQ
key:                  hslua-classes-2.3.0-IHHHpBW0JcmD7Uey6ib0yQ
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Type classes for HsLua
description:
    Type classes for convenient marshalling and calling of
    Lua functions.

category:             Foreign
abi:                  4163c604d0f4d7256f03841ba2cdf06f
exposed:              True
exposed-modules:
    HsLua.Class.Exposable HsLua.Class.Invokable HsLua.Class.Peekable
    HsLua.Class.Pushable HsLua.Class.Util HsLua.Classes

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-classes
hs-libraries:         HShslua-classes-2.3.0-IHHHpBW0JcmD7Uey6ib0yQ
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-core-2.3.1-E06t7plGrnBDHupIlwsSDy
    hslua-marshalling-2.3.1-FKnTNKxLu13GHBud3fPoiF text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-classes/html/hslua-classes.haddock

haddock-html:         /usr/share/doc/haskell-hslua-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-classes-2.3.0-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-classes
version:              2.3.0
visibility:           public
id:                   hslua-classes-2.3.0-S3na4x2DfIDMZXMT6hnV4
key:                  hslua-classes-2.3.0-S3na4x2DfIDMZXMT6hnV4
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Type classes for HsLua
description:
    Type classes for convenient marshalling and calling of
    Lua functions.

category:             Foreign
abi:                  809a7d72fc73b5879c8a960842ad679e
exposed:              True
exposed-modules:
    HsLua.Class.Exposable HsLua.Class.Invokable HsLua.Class.Peekable
    HsLua.Class.Pushable HsLua.Class.Util HsLua.Classes

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-classes-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-classes
hs-libraries:         HShslua-classes-2.3.0-S3na4x2DfIDMZXMT6hnV4
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-core-2.3.1-I595f6SepGBKiiOWyHoCYw
    hslua-marshalling-2.3.1-Kmh4dtpx5ALIXNkbyqbJIu text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-classes/html/hslua-classes.haddock

haddock-html:         /usr/share/doc/haskell-hslua-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
